hex

package
v0.0.0-...-0e9a772 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 1, 2025 License: CC0-1.0 Imports: 4 Imported by: 0

Documentation

Overview

Package hex is a set of aliases and helpers for using the templexxx SIMD hex encoder.

Index

Constants

This section is empty.

Variables

var DecBytes = hex.Decode
var DecLen = hex.DecodedLen
var EncBytes = hex.Encode

Functions

func DecAppend

func DecAppend(dst, src []byte) (b []byte, err error)

DecAppend decodes a provided encoded hex encoded string and appends the decoded output to a provided input slice.

func EncAppend

func EncAppend(dst, src []byte) (b []byte)

EncAppend uses xhex to encode a slice of bytes and appends it to a provided destination slice.

Types

type InvalidByteError

type InvalidByteError = hex.InvalidByteError

Jump to